@@ -324,7 +324,7 @@ queries until after they have been run.
 =cut
 
 package Test::DBIC::ExpectedQueries;
-$Test::DBIC::ExpectedQueries::VERSION = '1.010';
+$Test::DBIC::ExpectedQueries::VERSION = '1.011';
 use Moo;
 use Exporter::Tiny;
 BEGIN {extends "Exporter::Tiny"};
@@ -444,6 +444,7 @@ sub _stack_trace {
 sub run {
     my $self = shift;
     my ($subref) = @_;
+    my $wantarray = wantarray(); # Avoid it being masked in side try-catch block
 
     my $storage = $self->schema->storage;
 
@@ -468,7 +469,7 @@ sub run {
 
     my $return_values;
     try {
-        if (wantarray()) {
+        if ($wantarray) {
             $return_values = [ $subref->() ];
         }
         else {
@@ -483,7 +484,7 @@ sub run {
 
     $self->queries([ @{$self->queries}, @queries ]);
 
-    return @$return_values if wantarray();
+    return @$return_values if $wantarray;
     return $return_values->[0];
 }
 
